@@ -23,13 +23,16 @@ Copyright (C) 2020  Martin Röbke
 
 import re
 import logging
+from pathlib import Path
 from typing import Union, Iterable, List, Dict
+
 from benedict import benedict
 
 from tdvisu.utilities import gen_arg
 
 LOGGER = logging.getLogger('svg_join.py')
 
+
 # indices
 WIDTH = 2
 HEIGHT = 3
@@ -305,14 +308,11 @@ def svg_join(
     if len(base_names) == 1:
         LOGGER.warning("svg_join called with one file - nothing to join!")
         return
-    # could use path library for normalizing the path
-    if folder:
-        folder.replace('\\', '/')
-        if not folder.endswith('/'):
-            folder += '/'
+    # use path library for normalizing the path
+    folder = Path(folder if folder else '')
 
-    resultname = folder + outname + suffix
-    names = [folder + name + suffix for name in base_names]
+    resultname = str(folder / outname) + suffix
+    names = [str(folder / name) + suffix for name in base_names]
 
     gen_padding = gen_arg(padding)
     gen_scale2 = gen_arg(scale2)
@@ -348,10 +348,10 @@ def svg_join(
 
 
 if __name__ == "__main__":
-
-    svg_join(['TDStep', 'PrimalGraphStep', 'IncidenceGraphStep'],
-             'Archive/DA4',
-             num_images=6,
-             padding=40,
-             scale2=.3,
-             v_bottom=1)
+    logging.basicConfig(level=logging.DEBUG)
+    svg_join(['TDStep', 'graph'],
+             'Archive/WheelGraph7',
+             outname="default_06sc15_rise",
+             v_bottom=[1, .85, .7, .55, .4],
+             scale2=1.5,
+             num_images=5)
