@@ -27,7 +27,7 @@ import logging
 import logging.config
 from itertools import chain
 from pathlib import Path
-from typing import Generator, Any, Iterable, Iterator, TypeVar, Union, Optional
+from typing import Any, Generator, Iterable, Iterator, List, Tuple, TypeVar, Union
 import yaml
 
 LOGGER = logging.getLogger('utilities.py')
@@ -146,13 +146,20 @@ def read_yml_or_cfg(file: Union[str, Path], prefer_cfg: bool = False,
 
 
 def logging_cfg(filename: str, prefer_cfg: bool = False,
-                loglevel: Optional[int] = None) -> None:
+                loglevel: Union[None, int, str] = None) -> None:
     """Configure logging for this module"""
-    LOGGER.info("Read logging configuration from %s", filename)
+    logging.basicConfig()
     read_err = "could not read configuration from '%s'"
     config_err = "could not use logging configuration from '%s'"
+    # should be in same directory
+    file = Path(__file__).parent / filename
+
+    if loglevel is not None:
+        try:
+            loglevel = int(float(loglevel))
+        except ValueError:
+            loglevel = loglevel.upper()
 
-    file = Path(filename)
     if prefer_cfg or file.suffix.lower() in CFG_EXT:        # .config
         try:
             logging.config.fileConfig(file, defaults=DEFAULT_LOGGING_CFG)
@@ -163,11 +170,11 @@ def logging_cfg(filename: str, prefer_cfg: bool = False,
                     handler.setLevel(loglevel)
             return
         except OSError:
-            LOGGER.warning(read_err, file.resolve())
-        except BaseException:   # too general - can we be more specific?
-            LOGGER.warning(config_err, file.resolve())
+            LOGGER.error(read_err, file.resolve(), exc_info=True)
+        except ValueError:
+            LOGGER.error(config_err, file.resolve(), exc_info=True)
     try:                                                    # dict
-        file_content = read_yml_or_cfg(filename, prefer_cfg=prefer_cfg)
+        file_content = read_yml_or_cfg(file, prefer_cfg=prefer_cfg)
         logging.config.dictConfig(file_content)
         if loglevel is not None:
             root = logging.getLogger()
@@ -176,12 +183,13 @@ def logging_cfg(filename: str, prefer_cfg: bool = False,
                 handler.setLevel(loglevel)
         return
     except OSError:
-        LOGGER.warning(read_err, file.resolve())
-    except BaseException:   # too general - can we be more specific?
-        LOGGER.warning(config_err, file.resolve())
+        LOGGER.error(read_err, file.resolve(), exc_info=True)
+    except ValueError:
+        LOGGER.error(config_err, file.resolve(), exc_info=True)
 
 
-def convert_to_adj(edgelist, directed=False) -> dict:
+def convert_to_adj(
+        edgelist: Iterable[Tuple[int, int]], directed: bool = False) -> dict:
     """
     Helper function to convert the edgelist into the adj-format from NetworkX.
 
@@ -214,7 +222,11 @@ def convert_to_adj(edgelist, directed=False) -> dict:
     return adj
 
 
-def add_edge_to(edges, adjacency_dict, vertex1, vertex2) -> None:
+def add_edge_to(
+        edges: set,
+        adjacency_dict: dict,
+        vertex1: Any,
+        vertex2: Any) -> None:
     """
     Adding (undirected) edge from 'vertex1' to 'vertex2'
     to the edges and adjacency-list.
@@ -273,34 +285,44 @@ def gen_arg(arg_or_iter: Any) -> Generator:
         yield item
 
 
-def base_style(graph, node, color='white', penwidth='1.0') -> None:
+def base_style(
+        graph,
+        node: str,
+        color: str = 'white',
+        penwidth: float = 1.0) -> None:
     """Style the node with default fillcolor and penwidth."""
-    graph.node(node, fillcolor=color, penwidth=penwidth)
+    graph.node(node, fillcolor=color, penwidth=str(penwidth))
 
 
-def emphasise_node(graph, node, color='yellow',
-                   penwidth='2.5') -> None:
+def emphasise_node(graph, node: str, color: str = 'yellow',
+                   penwidth: float = 2.5) -> None:
     """Emphasise node with a different fillcolor (default:'yellow')
     and penwidth (default:2.5).
     """
     if color:
         graph.node(node, fillcolor=color)
     if penwidth:
-        graph.node(node, penwidth=penwidth)
+        graph.node(node, penwidth=str(penwidth))
 
 
-def style_hide_node(graph, node) -> None:
+def style_hide_node(graph, node: str) -> None:
     """Make the node invisible during drawing."""
     graph.node(node, style='invis')
 
 
-def style_hide_edge(graph, source, target) -> None:
+def style_hide_edge(graph, source: str, target: str) -> None:
     """Make the edge source->target invisible during drawing."""
     graph.edge(source, target, style='invis')
 
 
-def bag_node(head, tail, anchor='anchor', headcolor='white',
-             tableborder=0, cellborder=0, cellspacing=0) -> str:
+def bag_node(
+        head,
+        tail,
+        anchor: str = 'anchor',
+        headcolor: str = 'white',
+        tableborder: int = 0,
+        cellborder: int = 0,
+        cellspacing: int = 0) -> str:
     """HTML format with 'head' as the first label, then appending
     further labels.
 
@@ -326,7 +348,7 @@ def bag_node(head, tail, anchor='anchor', headcolor='white',
 
 
 def solution_node(
-        solution_table,
+        solution_table: Iterable[List[str]],
         toplabel: str = '',
         bottomlabel: str = '',
         transpose: bool = False,
